@@ -1,4 +1,4 @@
-/* $OpenBSD: sha_locl.h,v 1.17 2014/07/09 16:06:13 miod Exp $ */
+/* $OpenBSD: sha_locl.h,v 1.18 2014/08/18 19:11:48 bcook Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -206,7 +206,7 @@ int SHA1_Init(SHA_CTX *c)
 static void HASH_BLOCK_DATA_ORDER (SHA_CTX *c, const void *p, size_t num)
 	{
 	const unsigned char *data=p;
-	register unsigned MD32_REG_T A,B,C,D,E,T,l;
+	unsigned MD32_REG_T A,B,C,D,E,T,l;
 #ifndef MD32_XARRAY
 	unsigned MD32_REG_T	XX0, XX1, XX2, XX3, XX4, XX5, XX6, XX7,
 				XX8, XX9,XX10,XX11,XX12,XX13,XX14,XX15;
@@ -391,7 +391,7 @@ static void HASH_BLOCK_DATA_ORDER (SHA_CTX *c, const void *p, size_t num)
 static void HASH_BLOCK_DATA_ORDER (SHA_CTX *c, const void *p, size_t num)
 	{
 	const unsigned char *data=p;
-	register unsigned MD32_REG_T A,B,C,D,E,T,l;
+	unsigned MD32_REG_T A,B,C,D,E,T,l;
 	int i;
 	SHA_LONG	X[16];
 
